aboutsummaryrefslogtreecommitdiff
path: root/loader/loader.h
diff options
context:
space:
mode:
Diffstat (limited to 'loader/loader.h')
-rw-r--r--loader/loader.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/loader/loader.h b/loader/loader.h
index daf663eb..fc035ed3 100644
--- a/loader/loader.h
+++ b/loader/loader.h
@@ -166,7 +166,9 @@ struct loader_dev_dispatch_table {
// per CreateDevice structure
struct loader_device {
struct loader_dev_dispatch_table loader_dispatch;
- VkDevice device; // device object from the icd
+ VkDevice chain_device; // device object from the dispatch chain
+ VkDevice icd_device; // device object from the icd
+ struct loader_physical_device_term *phys_dev_term;
struct loader_layer_list activated_layer_list;
@@ -200,6 +202,8 @@ struct loader_icd_term {
PFN_vkCreateDebugReportCallbackEXT CreateDebugReportCallbackEXT;
PFN_vkDestroyDebugReportCallbackEXT DestroyDebugReportCallbackEXT;
PFN_vkDebugReportMessageEXT DebugReportMessageEXT;
+ PFN_vkDebugMarkerSetObjectTagEXT DebugMarkerSetObjectTagEXT;
+ PFN_vkDebugMarkerSetObjectNameEXT DebugMarkerSetObjectNameEXT;
PFN_vkGetPhysicalDeviceSurfaceSupportKHR GetPhysicalDeviceSurfaceSupportKHR;
PFN_vkGetPhysicalDeviceSurfaceCapabilitiesKHR
GetPhysicalDeviceSurfaceCapabilitiesKHR;
@@ -526,8 +530,7 @@ void loader_init_dispatch_dev_ext(struct loader_instance *inst,
struct loader_device *dev);
void *loader_dev_ext_gpa(struct loader_instance *inst, const char *funcName);
void *loader_get_dev_ext_trampoline(uint32_t index);
-void loader_override_terminating_device_proc(
- VkDevice device, struct loader_dev_dispatch_table *disp_table);
+void loader_override_terminating_device_proc(struct loader_device *dev);
struct loader_instance *loader_get_instance(const VkInstance instance);
void loader_deactivate_layers(const struct loader_instance *instance,
struct loader_device *device,